@@ -61,7 +61,7 @@ void ExampleWindow::on_button_dialog_clicked()
 {
   if (!m_pDialog)
   {
-    m_pDialog.reset(new Gtk::ColorChooserDialog("Please choose a color", *this));
+    m_pDialog = std::make_unique<Gtk::ColorChooserDialog>("Please choose a color", *this);
     m_pDialog->set_modal(true);
     m_pDialog->set_hide_on_close(true);
     m_pDialog->signal_response().connect(
@@ -71,12 +71,12 @@ void ExampleWindow::on_button_dialog_clicked()
   //Get the previously selected color:
   m_pDialog->set_rgba(m_Color);
 
-  m_pDialog->show();
+  m_pDialog->set_visible(true);
 }
 
 void ExampleWindow::on_dialog_response(int response_id)
 {
-  m_pDialog->hide();
+  m_pDialog->set_visible(false);
 
   //Handle the response:
   switch (response_id)
