@@ -155,7 +155,6 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
   Glib::ustring ui_toolbar_info =
     "<!-- Generated with glade 3.18.3 and then changed manually -->"
     "<interface>"
-      "<requires lib='gtk' version='3.98'/>"
       "<object class='GtkBox' id='toolbar'>"
         "<property name='can_focus'>False</property>"
         "<property name='spacing'>3</property>"
@@ -259,9 +258,9 @@ void ExampleWindow::on_printoperation_done(Gtk::PrintOperation::Result result)
         true /* modal */));
       m_pDialog->set_hide_on_close(true);
       m_pDialog->signal_response().connect(
-        sigc::hide(sigc::mem_fun(*m_pDialog, &Gtk::Widget::hide)));
+        [this](int /* response_id */){ m_pDialog->set_visible(false); });
     }
-    m_pDialog->show();
+    m_pDialog->set_visible(true);
   }
   else if (result == Gtk::PrintOperation::Result::APPLY)
   {
@@ -340,5 +339,5 @@ void ExampleWindow::on_menu_file_print()
 
 void ExampleWindow::on_menu_file_quit()
 {
-  hide();
+  set_visible(false);
 }
